# Arthexis Constellation

## Purpose
Arthexis Constellation is a narrative-driven Django-based suite that centralizes tools for managing charging infrastructure and orchestrating energy related products and services.

## Features
- Compatibility with all OCPP 1.6 certified chargers
- Native API integration with Odoo 1.6-based CRMs
- Runs everywhere Python 3.10+ is installed
- Single codebase with special features per role

## Support
You may contact us at tecnologia at gelectriic dot com or visit our [web page](https://www.gelectriic.com/) for professional services and commercial support.

## About Me
> "What? You want to know about me too? Well, I enjoy developing software, roleplaying games, long walks on the beach and a fourth secret thing."
> --Arthexis

